using System;
using System.Collections.Generic;
using System.Data;
using AcmeLibrary;
using UiPath.CodedWorkflows;
using UiPath.Core;
using UiPath.Core.Activities.Storage;
using UiPath.Orchestrator.Client.Models;
using UiPath.Testing;
using UiPath.Testing.Activities.TestData;
using UiPath.Testing.Activities.TestDataQueues.Enums;
using UiPath.Testing.Enums;
using UiPath.UIAutomationNext.API.Contracts;
using UiPath.UIAutomationNext.API.Models;
using UiPath.UIAutomationNext.Enums;

namespace UsingImportedLibraryProjects
{
    using AcmeApp = AcmeLibrary.ObjectRepository.Descriptors.Acme;
    
    public class AcmeStudentScoreCardWorkflow : CodedWorkflow
    {
        [Workflow]
        public void Execute()
        {
            // 1.Open the Acme app on the Login screen
            var AcmeLoginScreen = uiAutomation.Open(AcmeApp.LoginScreen);
            
             // 2.Type in the necessary credentials
            AcmeLoginScreen.TypeInto(AcmeApp.LoginScreen.Email, "john.doe2023@uipath.com");
            AcmeLoginScreen.TypeInto(AcmeApp.LoginScreen.Password, "12345678");
            // 3.Use a native selector to click the Login button
            AcmeLoginScreen.Click(Target.FromSelector("<webctrl tag='BUTTON' type='submit'/>"));
            
            // 4. Focus on the Dashboard screen
            var DashboardScreen = uiAutomation.Attach(AcmeApp.Dashboard);
            
            // 5. Click the Students entry
            DashboardScreen.Click(AcmeApp.Dashboard.Students);
            
            // 6. Click Score card, to start filling in a student score card
            DashboardScreen.Click(AcmeApp.Dashboard.Students.ScoreCard);
            
            // 7. Focus on the Score Card screen where you fill in the necessary information
            var ScoreCardScreen = uiAutomation.Attach(AcmeApp.StudentsScoreCard);
            
            // 8. Start filling in the fields in the score cards, for which you have descriptors in the Object Repository
            ScoreCardScreen.TypeInto(AcmeApp.StudentsScoreCard.StudentEmail, "john.doe@uipath.com");
            ScoreCardScreen.TypeInto(AcmeApp.StudentsScoreCard.FirstName, "John");
            ScoreCardScreen.TypeInto(AcmeApp.StudentsScoreCard.LastName, "Doe");
            ScoreCardScreen.TypeInto(AcmeApp.StudentsScoreCard.ParentEmail, "johnny.doe@uipath.com");
            ScoreCardScreen.TypeInto(AcmeApp.StudentsScoreCard.Tuition, "Private");
            
            // 9. Fill in the rest of the fields using native selectors that you discover through UI Explorer
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='mathematics' tag='INPUT' />"), "A");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='physics' tag='INPUT' />"), "B");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='biology' tag='INPUT' />"), "C");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='chemistry' tag='INPUT' />"), "A");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='geography' tag='INPUT' />"), "C");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='history' tag='INPUT' />"), "A");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='english' tag='INPUT' />"), "A");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='computer Science' tag='INPUT' />"), "C");
            ScoreCardScreen.TypeInto(Target.FromSelector("<webctrl id='professorComments' tag='INPUT' />"), "The student is doing okay, very hardworking and does its best");
            
            // 10. Click the "Add score card details" button using an Object Repository descriptor
            ScoreCardScreen.Click(AcmeApp.StudentsScoreCard.AddScoreCardDetailsButton);
            
            // 11. Invoke imported workflow from library
            RunWorkflow("notifyStudentScoreCardAdded.xaml");
            
            // 12. Close the applications/browsers you opened, to finish he automation
            ScoreCardScreen.Dispose();
        }
    }
            
}